CosmoBolognaLib
--------
C++ libraries for cosmological calculations

CosmoBolognaLib is a living project aimed at defining a common
numerical environment for cosmological investigations of the
large-scale structure of the Universe. In particular, one of the
primary focuses of this software is to help in handling astronomical
catalogues, both real and simulated, measuring one-point, two-point
and three-point statistics in configuration space, and performing
cosmological analyses.

For documentation and examples see here:
http://apps.difa.unibo.it/files/people/federico.marulli3/CosmoBolognaLib/Doc/html/index.html

If you use the CosmoBolognaLib, please reference the code paper:
CosmoBolognaLib: C++ libraries for cosmological calculations
http://arxiv.org/abs/1511.00012

To use, simply do::

    >>> import CosmoBolognaLib
    



    
